==> pdf-model-arlington-1.25.15-sources.jar: org/verapdf/model/alayer/APageLabel.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface APageLabel extends AObject {
	

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getPHasTypeStringText();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsSt();

	/**
	*/
	public Boolean getStHasTypeInteger();

	/**
	*/
	public Long getStIntegerValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}

==> pdf-model-arlington-1.25.55-sources.jar: org/verapdf/model/alayer/APageLabel.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface APageLabel extends AObject {
	

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeStringText();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public String getSType();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsSt();

	/**
	*/
	public String getStType();

	/**
	*/
	public Boolean getStHasTypeInteger();

	/**
	*/
	public Long getStIntegerValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}
